@@ -175,7 +175,7 @@ class ApiGatewayToKinesisStreams(
             put_records_request_template=put_records_request_template,
         )
 
-        jsii.create(ApiGatewayToKinesisStreams, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
